@@ -6,16 +6,17 @@
 
 import os
 import time
+from typing import List, Union, Optional, Dict
 from loguru import logger
 import numpy as np
+from numpy import ndarray
 from gensim.models import KeyedVectors
 from text2vec.utils.get_file import get_file
 from text2vec.utils.tokenizer import JiebaTokenizer
 
-USER_DATA_DIR = os.path.expanduser('~/.text2vec/datasets/')
-os.makedirs(USER_DATA_DIR, exist_ok=True)
-
 pwd_path = os.path.abspath(os.path.dirname(__file__))
+default_stopwords_file = os.path.join(pwd_path, 'data/stopwords.txt')
+USER_DATA_DIR = os.path.expanduser('~/.text2vec/datasets/')
 
 
 def load_stopwords(file_path):
@@ -45,21 +46,21 @@ class Word2Vec:
             'untar_filename': 'light_Tencent_AILab_ChineseEmbedding.bin'},
     }
 
-    def __init__(self, model_name_or_path='w2v-light-tencent-chinese',
-                 w2v_kwargs={},
-                 stopwords_file=os.path.join(pwd_path, 'data/stopwords.txt'),
+    def __init__(self, model_name_or_path: str = 'w2v-light-tencent-chinese',
+                 w2v_kwargs: Optional[Dict] = None,
+                 stopwords: Optional[List[str]] = None,
                  cache_folder=USER_DATA_DIR):
         """
         Init word2vec model
 
         Args:
             model_name_or_path: word2vec file path
-            w2v_kwargs: params pass to the ``load_word2vec_format()`` function of ``gensim.models.KeyedVectors`` -
+            w2v_kwargs: dict, params pass to the ``load_word2vec_format()`` function of ``gensim.models.KeyedVectors`` -
                 https://radimrehurek.com/gensim/models/keyedvectors.html#module-gensim.models.keyedvectors
-            stopwords_file: str, stopwords
-            cache_folder: str, save model
+            stopwords: list, stopwords
+            cache_folder: str, save model dir
         """
-        self.w2v_kwargs = w2v_kwargs
+        self.w2v_kwargs = w2v_kwargs if w2v_kwargs is not None else {}
         if model_name_or_path and os.path.exists(model_name_or_path):
             logger.info('Load pretrained model:{}'.format(model_name_or_path))
             model_path = model_name_or_path
@@ -71,21 +72,22 @@ class Word2Vec:
             untar_filename = model_dict.get('untar_filename')
             model_path = os.path.join(cache_folder, untar_filename)
             if not os.path.exists(model_path):
+                os.makedirs(cache_folder, exist_ok=True)
                 get_file(tar_filename, url, extract=True,
-                         cache_dir=USER_DATA_DIR,
-                         cache_subdir=USER_DATA_DIR,
+                         cache_dir=cache_folder,
+                         cache_subdir=cache_folder,
                          verbose=1)
         t0 = time.time()
         w2v = KeyedVectors.load_word2vec_format(model_path, **self.w2v_kwargs)
         # w2v.init_sims(replace=True)
         logger.debug('Load w2v from {}, spend {:.2f} sec'.format(model_name_or_path, time.time() - t0))
-        self.stopwords = load_stopwords(stopwords_file)
+        self.stopwords = stopwords if stopwords else load_stopwords(default_stopwords_file)
         self.w2v = w2v
         self.jieba_tokenizer = JiebaTokenizer()
         logger.debug('Word count: {}, emb size: {}'.format(len(w2v.key_to_index), w2v.vector_size))
         logger.debug('Set stopwords: {}, count: {}'.format(sorted(list(self.stopwords))[:10], len(self.stopwords)))
 
-    def encode(self, sentences):
+    def encode(self, sentences: Union[List[str], str]) -> Union[List, ndarray]:
         """
         Encode embed sentences
 
@@ -95,7 +97,7 @@ class Word2Vec:
             vectorized sentence list
         """
         if self.w2v is None:
-            raise ValueError('need to build model for embed sentence')
+            raise ValueError('No model for embed sentence')
 
         input_is_string = False
         if isinstance(sentences, str) or not hasattr(sentences, '__len__'):
@@ -127,9 +129,9 @@ class Word2Vec:
             if count > 0:
                 avg_tensor_x = np.divide(tensor_x, count)
             else:
-                avg_tensor_x = 0.0
+                avg_tensor_x = np.zeros(self.w2v.vector_size, dtype=float)
             all_embeddings.append(avg_tensor_x)
-        all_embeddings = np.array(all_embeddings, dtype=object)
+        all_embeddings = np.array(all_embeddings, dtype=float)
         if input_is_string:
             all_embeddings = all_embeddings[0]
 
